Learn R Programming

equivalenceTest (version 0.0.1.1)

equivTestFixedMargin: Conduct the equivalence test with fixed margin

Description

Conduct the equivalence test with fixed margin.

Usage

equivTestFixedMargin(vecT, vecR, alpha = 0.05, marginX = 1.5,
  sampleSizeX = 1.5, qa = "", sigmaTOverride = NULL,
  labelT = "Proposed", labelR = "Reference", show.message = FALSE,
  method = "Fixed Margin")

Arguments

vecT

the sample data for test product, can be a vector of observed values or a list returned by createEquivTestSmpl

vecR

the sample data for reference product, can be a vector of observed values or a list returned by createEquivTestSmpl

alpha

the nominal size, default = 0.05

marginX

the margin multiplier, default = 1.5

sampleSizeX

the sample size adjustment coefficient, default = 1.5

qa

a string representing the name of the quality attribute, default = ""

sigmaTOverride

a numeric value to override the estimate for standard deviation of the test product

labelT

the name of the test product, default = "Proposed"

labelR

the name of the reference product, default = "Reference"

show.message

a logic value indicating whether messages are to be shown, default = FALSE

method

a string indicating the method used in the equivalence test.

Value

a list of objects summarizing the data and test results, in particular, rslt = 1 if \(H_0\) is rejected, and rslt = 0 if \(H_0\) is not rejected.

References

tsong2017developmentequivalenceTest

Examples

Run this code
# NOT RUN {
vecT = rnorm(20,-1.5,1)
vecR = rnorm(20,0,1)
et = equivTestFixedMargin(vecT, vecR)

# }

Run the code above in your browser using DataLab