powered by
Conduct the equivalence test with fixed margin.
equivTestFixedMargin(vecT, vecR, alpha = 0.05, marginX = 1.5, sampleSizeX = 1.5, qa = "", sigmaTOverride = NULL, labelT = "Proposed", labelR = "Reference", show.message = FALSE, method = "Fixed Margin")
the sample data for test product, can be a vector of observed values or a list returned by createEquivTestSmpl
createEquivTestSmpl
the sample data for reference product, can be a vector of observed values or a list returned by createEquivTestSmpl
the nominal size, default = 0.05
the margin multiplier, default = 1.5
the sample size adjustment coefficient, default = 1.5
a string representing the name of the quality attribute, default = ""
a numeric value to override the estimate for standard deviation of the test product
the name of the test product, default = "Proposed"
the name of the reference product, default = "Reference"
a logic value indicating whether messages are to be shown, default = FALSE
a string indicating the method used in the equivalence test.
a list of objects summarizing the data and test results, in particular, rslt = 1 if \(H_0\) is rejected, and rslt = 0 if \(H_0\) is not rejected.
rslt
tsong2017developmentequivalenceTest
# NOT RUN { vecT = rnorm(20,-1.5,1) vecR = rnorm(20,0,1) et = equivTestFixedMargin(vecT, vecR) # }
Run the code above in your browser using DataLab